@@ -6,6 +6,9 @@ from dfk import point_named
 from dfk import repoint
 from dfk.models import DeferredForeignKey
 
+class CustomField(models.CharField):
+    __metaclass__ = models.SubfieldBase
+
 class ModelA(models.Model):
     pass
 
@@ -18,6 +21,10 @@ class ModelC(models.Model):
 class ModelD(models.Model):
     fk = DeferredForeignKey(name='content')
 
+class ModelCustomField(models.Model):
+    fk = DeferredForeignKey(name='content2')
+    other = CustomField(max_length=10)
+
 class NotAModel(object):
     pass
 
@@ -50,7 +57,7 @@ class ExistingTestCase(TestCase):
 
 class DeferredModelA(models.Model):
     user = DeferredForeignKey()
-    
+
 class DeferredModelB(models.Model):
     user = DeferredForeignKey()
 
@@ -60,6 +67,9 @@ point(DeferredModelA, 'user', ModelA, related_name='foo_set')
 # Point ModelD's deferred fk to ModelA
 point_named('dfk', 'content', ModelA)
 
+# Point ModelCustomFiekld's deferred fk to ModelA
+point_named('dfk', 'content2', ModelA)
+
 class DeferredForeignKeyTestCase(TestCase):
 
     def test_specific_field(self):
@@ -71,7 +81,7 @@ class DeferredForeignKeyTestCase(TestCase):
         )
         x = DeferredModelA.objects.get(pk=a.pk).user
         self.assertEqual(m, x)
-        
+
         # Also test that the related_name override was passed
         # through
         self.assertEqual(1, len(x.foo_set.all()))
@@ -80,20 +90,27 @@ class DeferredForeignKeyTestCase(TestCase):
         # Attempting to point a dfk to a different target once
         # it's already been set should raise an error
         self.assertRaises(ValueError, point, DeferredModelA, 'user', ModelC)
-        
+
     def test_point_non_deferred(self):
-        # Attempting to point a non-DeferredForeignKey should raise a 
+        # Attempting to point a non-DeferredForeignKey should raise a
         # ValueError
         self.assertRaises(ValueError, point, ModelB, 'fk', ModelC)
-        
+
     def test_point_abstract(self):
         # Attempting to point a dfk to an abstract class should raise
         # a AssertionError
         self.assertRaises(AssertionError, point, DeferredModelB, 'user', AbstractModel)
-        
+
     def test_named_deferred(self):
         # Check that our repoint of the named foreign key worked
         a = ModelA.objects.create()
         d = ModelD.objects.create(fk=a)
         self.assertEqual(a, ModelD.objects.get(pk=d.pk).fk)
-        
\ No newline at end of file
+
+    def test_class_using_custom_fields_with_subfield_base(self):
+        # Check that we our repoint of the named fk on the model with a
+        # custom field worked
+        a = ModelA.objects.create()
+        d = ModelCustomField.objects.create(fk=a, other='hi')
+        self.assertEqual(a, ModelCustomField.objects.get(pk=d.pk).fk)
+
